#[non_exhaustive]pub struct CreateProxySessionInput {
pub voice_connector_id: Option<String>,
pub participant_phone_numbers: Option<Vec<String>>,
pub name: Option<String>,
pub expiry_minutes: Option<i32>,
pub capabilities: Option<Vec<Capability>>,
pub number_selection_behavior: Option<NumberSelectionBehavior>,
pub geo_match_level: Option<GeoMatchLevel>,
pub geo_match_params: Option<GeoMatchParams>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.voice_connector_id: Option<String>The Voice Connector ID.
participant_phone_numbers: Option<Vec<String>>The participant phone numbers.
name: Option<String>The name of the proxy session.
expiry_minutes: Option<i32>The number of minutes allowed for the proxy session.
capabilities: Option<Vec<Capability>>The proxy session's capabilities.
number_selection_behavior: Option<NumberSelectionBehavior>The preference for proxy phone number reuse, or stickiness, between the same participants across sessions.
geo_match_level: Option<GeoMatchLevel>The preference for matching the country or area code of the proxy phone number with that of the first participant.
geo_match_params: Option<GeoMatchParams>The country and area code for the proxy phone number.
Implementations
Sourceimpl CreateProxySessionInput
impl CreateProxySessionInput
Sourcepub fn voice_connector_id(&self) -> Option<&str>
pub fn voice_connector_id(&self) -> Option<&str>
The Voice Connector ID.
Sourcepub fn participant_phone_numbers(&self) -> &[String]
pub fn participant_phone_numbers(&self) -> &[String]
The participant phone numbers.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .participant_phone_numbers.is_none().
Sourcepub fn expiry_minutes(&self) -> Option<i32>
pub fn expiry_minutes(&self) -> Option<i32>
The number of minutes allowed for the proxy session.
Sourcepub fn capabilities(&self) -> &[Capability]
pub fn capabilities(&self) -> &[Capability]
The proxy session's capabilities.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .capabilities.is_none().
Sourcepub fn number_selection_behavior(&self) -> Option<&NumberSelectionBehavior>
pub fn number_selection_behavior(&self) -> Option<&NumberSelectionBehavior>
The preference for proxy phone number reuse, or stickiness, between the same participants across sessions.
Sourcepub fn geo_match_level(&self) -> Option<&GeoMatchLevel>
pub fn geo_match_level(&self) -> Option<&GeoMatchLevel>
The preference for matching the country or area code of the proxy phone number with that of the first participant.
Sourcepub fn geo_match_params(&self) -> Option<&GeoMatchParams>
pub fn geo_match_params(&self) -> Option<&GeoMatchParams>
The country and area code for the proxy phone number.
Sourceimpl CreateProxySessionInput
impl CreateProxySessionInput
Sourcepub fn builder() -> CreateProxySessionInputBuilder
pub fn builder() -> CreateProxySessionInputBuilder
Creates a new builder-style object to manufacture CreateProxySessionInput.